@@ -205,7 +205,7 @@ void UI::setupActions()
   settingsAction = new QAction(tr("Settings"),this);
   connect(settingsAction, SIGNAL(triggered()), this, SLOT(settingsDialogOpen()));
   
-  loadPlaylist =  new QAction(tr("Load Playlist"),this);
+  loadPlaylist =  new QAction(tr("Open Playlist"),this);
   connect(loadPlaylist, SIGNAL(triggered()), this, SLOT(loadPlaylistDialog()));
   
   savePlaylist =  new QAction(tr("Save Playlist"),this);
