@@ -9,14 +9,15 @@
 //#include "UISettings.h"
 #include "UIControl.h"
 #include "SettingsDialog.h"
+#include "UrlDialog.h"
 
-class UPlay;
+class Player;
 
 class UI : public QMainWindow
 {
 		Q_OBJECT
 	public:
-		UI(UPlay* parent,QString& musicPath);
+		UI(Player* parent,QString& musicPath);
 		~UI();
 
 		/*
@@ -32,7 +33,7 @@ class UI : public QMainWindow
 		
 		void addItem(QString s);
 		
-		void changeItem(QString s,int row);
+		void changeItem(QString s,int row, bool disable=false);
 
 		void setInfos(QString s);
 
@@ -43,6 +44,7 @@ class UI : public QMainWindow
 		{
 			return playlist->currentRow();
 		}
+
 		/*
 		 * Return how many files in the playlist
 		 */
@@ -86,6 +88,12 @@ class UI : public QMainWindow
 		
 		void settingsDialogOpen();
 		void settingsDialogAccepted();
+		
+		void savePlaylistDialog();
+		void loadPlaylistDialog();
+		
+		void openUrlDialog();
+		void urlDialogAccepted();
 
 		// Tray quit
 		//void tQuit();
@@ -112,14 +120,19 @@ class UI : public QMainWindow
 		QVBoxLayout* infosLayout;
 		QLabel* infosSong;
 		
+		QString workdir;
+		
 		QAction *settingsAction;
-		QMenu *settingsMenu;
+		QAction *loadPlaylist,*savePlaylist;
+		QAction *openUrl;
+		QMenu *settingsMenu,*fileMenu;
 		
 		SettingsDialog *settingsdialog;
+		UrlDialog *urldialog;
 
 
 
-		UPlay* parent;
+		Player* parent;
 };
 
 #endif // UI_H
