@@ -3,7 +3,7 @@
 
 #include <QtGui>
 
-class UPlay;
+class Player;
 
 class UIFolder : public QWidget
 {
@@ -12,7 +12,7 @@ class UIFolder : public QWidget
 		/*
 		 * Constructor
 		 */
-		UIFolder(UPlay* parent, QString musicPath);
+		UIFolder(Player* parent, QString musicPath);
 		~UIFolder();
  
 		/*
@@ -60,7 +60,7 @@ class UIFolder : public QWidget
 		QStringList getMediaFilesInDir(QString uri);
 		bool fileIsGood(QString uri);
 
-		UPlay* parent;
+		Player* parent;
 };
 
 #endif // UIFOLDER_H
